@@ -89,6 +89,9 @@ class CTkSlider(tkinter.Frame):
         self.canvas.bind("<Button-1>", self.clicked)
         self.canvas.bind("<B1-Motion>", self.clicked)
 
+        # Each time an item is resized due to pack position mode, the binding Configure is called on the widget
+        self.bind('<Configure>', self.update_dimensions)
+
         self.draw()  # initial draw
 
         if self.variable is not None:
@@ -126,6 +129,14 @@ class CTkSlider(tkinter.Frame):
             else:
                 return user_height
 
+    def update_dimensions(self, event):
+        # only redraw if dimensions changed (for performance)
+        if self.width != event.width or self.height != event.height:
+            self.width = event.width
+            self.height = event.height
+
+            self.draw()
+
     def draw(self, no_color_updates=False):
 
         # decide the drawing method
